<?php

	App::uses('EvTeamAppModel', 'EvTeam.Model');

	/**
	 * Business rules for Pages
	 */
	class TeamMember extends EvTeamAppModel {

		public $displayField = 'name';

		public $actsAs = array(
			'MetaData.Meta',
			'EvTemplates.Template' => array(
				'formInject' => true,
				'restrictTo' => 'Product'
			)
		);

		public $validate = array(
			'name' => array(
				'required' => array(
					'rule' => 'notEmpty',
					'message' => 'cannot be blank'
				)
			),
		);

		public $imageSlots = array(
			'main' => array(
				'slots' => 1,
				'fields' => array()
			),
		);

		public $hasAndBelongsToMany = array(
			'EvTeam.Department',
		);

		/**
		 * Method to get TeamMembers when not using readForIndex()
		 * @param   $departmentId 	Pass this is in to get the team for the
		 *                          current department only.
		 * @return   array
		 */
		public function getTeam($departmentId = null) {
			$alias = $this->alias;

			$team = $this->find('all',
				[
					'conditions' => [
						"$alias.is_active" => 1
					],
					'contain' => [
						'Image',
						'Department' => [
							'conditions' => [
								'Department.id' => $departmentId
							]
						]
					],
					'order' => array("$alias.sequence ASC", "$alias.name ASC"),
				]
			);
			return $team;
		}

		/**
		 * Method to return any featured teamMembers in a random order.
		 * @return   array
		 */
		public function getFeatured() {
			return $this->find('all', array(
				'conditions' => array(
					"$alias.is_featured" => 1,
					"$alias.is_active" => 1,
				),
				'contain' => 'Image',
				'order' => 'RAND()'
			));
		}

	}
